@@ -489,6 +489,20 @@ void anjuta_shell_unmaximize (AnjutaShell *shell,
 	ANJUTA_SHELL_GET_IFACE (shell)->unmaximize (shell, error);
 }
 
+/**
+ * anjuta_shell_create_window:
+ * @shell: A #AnjutaShell interface
+ * @error: Error propagation object.
+ * 
+ * Create a new main window in the same process.
+ */
+AnjutaShell*
+anjuta_shell_create_window (AnjutaShell  *shell,
+                         GError		   **error)
+{
+	return ANJUTA_SHELL_GET_IFACE (shell)->create_window (shell, error);
+}
+
 /**
  * anjuta_shell_add_value:
  * @shell: A #AnjutaShell interface
@@ -913,31 +927,68 @@ anjuta_shell_session_load (AnjutaShell *shell, const gchar *session_directory,
 						   GError **error)
 {
 	AnjutaSession *session;
-
+	AnjutaSession *child;
+ 
 	g_return_if_fail (ANJUTA_IS_SHELL (shell));
 	g_return_if_fail (session_directory != NULL);
+ 
+	/* It is possible that loading a session triggers the load on another
+	 * session. It happens when restoring an user session includes a project.
+	 * The project session is loaded while the user session is still loading. */
+	session = anjuta_session_new (session_directory);
 
-	/* Do not allow multiple session loadings at once. Could be a trouble */
-	if (g_object_get_data (G_OBJECT (shell), "__session_loading"))
+	child = g_object_get_data (G_OBJECT (shell), "__session_loading");
+	g_object_set_data (G_OBJECT (shell), "__session_loading", session);
+	if (child != NULL)
 	{
-		/* DEBUG_PRINT ("%s", "A session load is requested in the middle of another!!"); */
+		/* There is already a session loading.
+		 * Replace it with our own session. The previous session will be
+		 * aborted and our session will be loaded afterward. */
+		g_object_unref (G_OBJECT (child));
+
 		return;
 	}
-	g_object_set_data (G_OBJECT (shell), "__session_loading", "1");
 
-	session = anjuta_session_new (session_directory);
-	g_signal_emit_by_name (G_OBJECT (shell), "load_session",
-						   ANJUTA_SESSION_PHASE_START, session);
-	g_signal_emit_by_name (G_OBJECT (shell), "load_session",
-						   ANJUTA_SESSION_PHASE_FIRST, session);
-	g_signal_emit_by_name (G_OBJECT (shell), "load_session",
-						   ANJUTA_SESSION_PHASE_NORMAL, session);
-	g_signal_emit_by_name (G_OBJECT (shell), "load_session",
-						   ANJUTA_SESSION_PHASE_LAST, session);
-	g_signal_emit_by_name (G_OBJECT (shell), "load_session",
-						   ANJUTA_SESSION_PHASE_END, session);
-	g_object_unref (session);
+	/* This is the top session. This code emits all signals and check after
+	 * each phase that the session is still the same. If it is not the case
+	 * the session is aborted and the new session is loaded. */
+	for (;;)
+	{
+		if (child != NULL)
+		{
+			/* Abort previous session */
+			g_signal_emit_by_name (G_OBJECT (shell), "load_session",
+								   ANJUTA_SESSION_PHASE_END, session);
+			g_object_unref (session);
+			/* Reread session in case PHASE_END has triggered another session */
+			session = g_object_get_data (G_OBJECT (shell), "__session_loading");
+		}
+		g_object_ref (session);
 
+		g_signal_emit_by_name (G_OBJECT (shell), "load_session",
+							   ANJUTA_SESSION_PHASE_START, session);
+		child = g_object_get_data (G_OBJECT (shell), "__session_loading");
+		if (child != session) continue;
+		g_signal_emit_by_name (G_OBJECT (shell), "load_session",
+							   ANJUTA_SESSION_PHASE_FIRST, session);
+		child = g_object_get_data (G_OBJECT (shell), "__session_loading");
+		if (child != session) continue;
+		g_signal_emit_by_name (G_OBJECT (shell), "load_session",
+							   ANJUTA_SESSION_PHASE_NORMAL, session);
+		child = g_object_get_data (G_OBJECT (shell), "__session_loading");
+		if (child != session) continue;
+		g_signal_emit_by_name (G_OBJECT (shell), "load_session",
+ 							   ANJUTA_SESSION_PHASE_LAST, session);
+		child = g_object_get_data (G_OBJECT (shell), "__session_loading");
+		if (child != session) continue;
+		g_signal_emit_by_name (G_OBJECT (shell), "load_session",
+							   ANJUTA_SESSION_PHASE_END, session);
+		child = g_object_get_data (G_OBJECT (shell), "__session_loading");
+		g_object_unref (session);
+		if (child == session) break;
+		session = child;
+		child = NULL;
+	}
 	g_object_set_data (G_OBJECT (shell), "__session_loading", NULL);
 }
 
