@@ -115,9 +115,7 @@ enum {
 };
 
 enum {
-	ID_NEXTBUFFER = 1, /* Note: the value mustn't be 0 ! */
-	ID_PREVBUFFER,
-	ID_FIRSTBUFFER
+	ID_FIRSTBUFFER = 1, /* Note: the value mustn't be 0 ! */
 };
 
 typedef struct {
@@ -127,14 +125,6 @@ typedef struct {
 } ShortcutMapping;
 
 static ShortcutMapping global_keymap[] = {
-/* FIXME: HIG requires that Ctrl+Tab be used to transfer focus in multiline
-   text entries. So we can't use the following ctrl+tabbing. Is there other
-   sensible keys that can be used for them?
-*/
-/*
-	{ m_C_, GDK_Tab,		 ID_NEXTBUFFER },
-	{ mSC_, GDK_ISO_Left_Tab, ID_PREVBUFFER },
-*/
 	{ m__M, GDK_KEY_1, ID_FIRSTBUFFER },
 	{ m__M, GDK_KEY_2, ID_FIRSTBUFFER + 1},
 	{ m__M, GDK_KEY_3, ID_FIRSTBUFFER + 2},
@@ -532,10 +522,10 @@ value_added_project_root_uri (AnjutaPlugin *plugin, const gchar *name,
 
 	DEBUG_PRINT ("%s", "Project added");
 
-
 	g_free (doc_plugin->project_name);
 	g_free (doc_plugin->project_path);
 	doc_plugin->project_name = NULL;
+	doc_plugin->project_path = NULL;
 
 	if (doc_plugin->search_files)
 		search_files_update_project (SEARCH_FILES(doc_plugin->search_files));
@@ -554,6 +544,8 @@ value_added_project_root_uri (AnjutaPlugin *plugin, const gchar *name,
 			update_title (doc_plugin);
 		}
 		g_object_unref (file);
+
+		anjuta_docman_project_path_updated (ANJUTA_DOCMAN (doc_plugin->docman));
 	}
 }
 
@@ -568,13 +560,15 @@ value_removed_project_root_uri (AnjutaPlugin *plugin, const gchar *name,
 	DEBUG_PRINT ("%s", "Project removed");
 
 	g_free (doc_plugin->project_name);
+	g_free (doc_plugin->project_path);
 	doc_plugin->project_name = NULL;
+	doc_plugin->project_path = NULL;
 
 	if (doc_plugin->search_files)
 		search_files_update_project (SEARCH_FILES(doc_plugin->search_files));
 
-	
 	update_title(doc_plugin);
+	anjuta_docman_project_path_updated (ANJUTA_DOCMAN (doc_plugin->docman));
 }
 
 static void
@@ -633,6 +627,10 @@ update_document_ui_disable_all (AnjutaPlugin *plugin)
 	{
 		for (j = 0; j < action_groups[i].size; j++)
 		{
+			/* Never disable find in files. */
+			if (!strcmp (action_groups[i].group[j].name, "ActionEditFindFiles"))
+				continue;
+
 			action = anjuta_ui_get_action (ui, action_groups[i].name,
 										   action_groups[i].group[j].name);
 			if (action_groups[i].group[j].callback)
@@ -1230,6 +1228,54 @@ on_editor_lang_changed (IAnjutaEditor* editor,
 	                        ANJUTA_PLUGIN(plugin));
 }
 
+#define EDITOR_TABS_RECENT_FIRST   "docman-tabs-recent-first"
+#define EDITOR_TABS_POS            "docman-tabs-pos"
+#define EDITOR_SHOW_DROP_DOWN      "docman-show-drop-down"
+#define EDITOR_TABS_HIDE           "docman-tabs-hide"
+#define EDITOR_TABS_ORDERING       "docman-tabs-ordering"
+#define AUTOSAVE_TIMER             "docman-autosave-timer"
+#define SAVE_AUTOMATIC             "docman-automatic-save"
+
+static void
+docman_plugin_set_tab_pos (DocmanPlugin *ep)
+{
+
+	if (g_settings_get_boolean (ep->settings, EDITOR_SHOW_DROP_DOWN))
+	{
+		anjuta_docman_set_open_documents_mode (ANJUTA_DOCMAN (ep->docman),
+											   ANJUTA_DOCMAN_OPEN_DOCUMENTS_MODE_COMBO);
+	}
+	else if (g_settings_get_boolean (ep->settings, EDITOR_TABS_HIDE))
+	{
+		anjuta_docman_set_open_documents_mode (ANJUTA_DOCMAN (ep->docman),
+											   ANJUTA_DOCMAN_OPEN_DOCUMENTS_MODE_NONE);
+	}
+	else
+	{
+		gchar *tab_pos;
+		GtkPositionType pos;
+
+		anjuta_docman_set_open_documents_mode (ANJUTA_DOCMAN (ep->docman),
+											   ANJUTA_DOCMAN_OPEN_DOCUMENTS_MODE_TABS);
+		tab_pos = g_settings_get_string (ep->settings, EDITOR_TABS_POS);
+
+		pos = GTK_POS_TOP;
+		if (tab_pos)
+		{
+			if (strcasecmp (tab_pos, "top") == 0)
+				pos = GTK_POS_TOP;
+			else if (strcasecmp (tab_pos, "left") == 0)
+				pos = GTK_POS_LEFT;
+			else if (strcasecmp (tab_pos, "right") == 0)
+				pos = GTK_POS_RIGHT;
+			else if (strcasecmp (tab_pos, "bottom") == 0)
+				pos = GTK_POS_BOTTOM;
+			g_free (tab_pos);
+		}
+		anjuta_docman_set_tab_pos (ANJUTA_DOCMAN (ep->docman), pos);
+	}
+}
+
 static void
 on_document_added (AnjutaDocman *docman, IAnjutaDocument *doc,
 				   AnjutaPlugin *plugin)
@@ -1280,13 +1326,10 @@ on_window_key_press_event (AnjutaShell *shell,
 						   GdkEventKey *event,
 						  DocmanPlugin *plugin)
 {
-	gint modifiers;
 	gint i;
 
 	g_return_val_if_fail (event != NULL, FALSE);
 
-	modifiers = event->state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK);
-
 	for (i = 0; global_keymap[i].id; i++)
 		if (event->keyval == global_keymap[i].gdk_key &&
 		    (event->state & global_keymap[i].modifiers) == global_keymap[i].modifiers)
@@ -1295,47 +1338,16 @@ on_window_key_press_event (AnjutaShell *shell,
 	if (!global_keymap[i].id)
 		return FALSE;
 
-	switch (global_keymap[i].id) {
-	case ID_NEXTBUFFER:
-	case ID_PREVBUFFER:
+	if (global_keymap[i].id >= ID_FIRSTBUFFER &&
+			    global_keymap[i].id <= (ID_FIRSTBUFFER + 9))
 	{
-		GtkNotebook *notebook = GTK_NOTEBOOK (plugin->docman);
-		gint pages_nb;
-		gint cur_page;
+		gint page_req = global_keymap[i].id - ID_FIRSTBUFFER;
 
-		if ((cur_page = gtk_notebook_get_current_page (notebook)) == -1);
-			return FALSE;
-
-		if (!plugin->g_tabbing)
-		{
-			plugin->g_tabbing = TRUE;
-		}
-
-		pages_nb = gtk_notebook_get_n_pages (notebook);
-
-		if (global_keymap[i].id == ID_NEXTBUFFER)
-			cur_page = (cur_page < pages_nb - 1) ? cur_page + 1 : 0;
-		else
-			cur_page = cur_page ? cur_page - 1 : pages_nb -1;
-
-		gtk_notebook_set_current_page (notebook, cur_page);
-
-		break;
-	}
-	default:
-		if (global_keymap[i].id >= ID_FIRSTBUFFER &&
-		  global_keymap[i].id <= (ID_FIRSTBUFFER + 9))
-		{
-			GtkNotebook *notebook = GTK_NOTEBOOK (plugin->docman);
-			gint page_req = global_keymap[i].id - ID_FIRSTBUFFER;
-
-			if (gtk_notebook_get_n_pages (notebook) == 0);
-				return FALSE;
-			gtk_notebook_set_current_page(notebook, page_req);
-		}
-		else
+		if (!anjuta_docman_set_page (ANJUTA_DOCMAN(plugin->docman), page_req))
 			return FALSE;
 	}
+	else
+		return FALSE;
 
 	/* Note: No reason for a shortcut to do more than one thing a time */
 	g_signal_stop_emission_by_name (G_OBJECT (ANJUTA_PLUGIN(plugin)->shell),
@@ -1344,43 +1356,6 @@ on_window_key_press_event (AnjutaShell *shell,
 	return TRUE;
 }
 
-#define EDITOR_TABS_RECENT_FIRST   "docman-tabs-recent-first"
-#define EDITOR_TABS_POS            "docman-tabs-pos"
-#define EDITOR_TABS_HIDE           "docman-tabs-hide"
-#define EDITOR_TABS_ORDERING       "docman-tabs-ordering"
-#define AUTOSAVE_TIMER             "docman-autosave-timer"
-#define SAVE_AUTOMATIC             "docman-automatic-save"
-
-static gboolean
-on_window_key_release_event (AnjutaShell *shell,
-							 GdkEventKey *event,
-							DocmanPlugin *plugin)
-{
-	g_return_val_if_fail (event != NULL, FALSE);
-
-	if (plugin->g_tabbing && ((event->keyval == GDK_KEY_Control_L) ||
-		(event->keyval == GDK_KEY_Control_R)))
-	{
-		GtkNotebook *notebook = GTK_NOTEBOOK (plugin->docman);
-		GtkWidget *widget;
-		gint cur_page;
-		plugin->g_tabbing = FALSE;
-
-		if (g_settings_get_boolean (plugin->settings,
-		                            EDITOR_TABS_RECENT_FIRST))
-		{
-			/*
-			TTimo: move the current notebook page to first position
-			that maintains Ctrl-TABing on a list of most recently edited files
-			*/
-			cur_page = gtk_notebook_get_current_page (notebook);
-			widget = gtk_notebook_get_nth_page (notebook, cur_page);
-			gtk_notebook_reorder_child (notebook, widget, 0);
-		}
-	}
-	return FALSE;
-}
-
 static void
 on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase,
 				 AnjutaSession *session, DocmanPlugin *plugin)
@@ -1486,38 +1461,6 @@ on_save_prompt (AnjutaShell *shell, AnjutaSavePrompt *save_prompt,
 	}
 }
 
-static void
-docman_plugin_set_tab_pos (DocmanPlugin *ep)
-{
-	if (g_settings_get_boolean (ep->settings, EDITOR_TABS_HIDE))
-	{
-		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (ep->docman), FALSE);
-	}
-	else
-	{
-		gchar *tab_pos;
-		GtkPositionType pos;
-
-		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (ep->docman), TRUE);
-		tab_pos = g_settings_get_string (ep->settings, EDITOR_TABS_POS);
-
-		pos = GTK_POS_TOP;
-		if (tab_pos)
-		{
-			if (strcasecmp (tab_pos, "top") == 0)
-				pos = GTK_POS_TOP;
-			else if (strcasecmp (tab_pos, "left") == 0)
-				pos = GTK_POS_LEFT;
-			else if (strcasecmp (tab_pos, "right") == 0)
-				pos = GTK_POS_RIGHT;
-			else if (strcasecmp (tab_pos, "bottom") == 0)
-				pos = GTK_POS_BOTTOM;
-			g_free (tab_pos);
-		}
-		gtk_notebook_set_tab_pos (GTK_NOTEBOOK (ep->docman), pos);
-	}
-}
-
 static void
 on_notify_prefs (AnjutaPreferences* prefs,
                  const gchar* key, gpointer user_data)
@@ -1595,12 +1538,10 @@ on_notify_timer (GSettings* settings,
                  gpointer user_data)
 {
 	DocmanPlugin *plugin;
-	AnjutaDocman *docman;
 	gint auto_save_timer;
 	gboolean auto_save;
 
 	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
-	docman = ANJUTA_DOCMAN (plugin->docman);
 
 	auto_save_timer = g_settings_get_int(settings, AUTOSAVE_TIMER);
 	auto_save = g_settings_get_boolean(settings, SAVE_AUTOMATIC);
@@ -1638,6 +1579,8 @@ prefs_init (DocmanPlugin *ep)
 {
 	docman_plugin_set_tab_pos (ep);
 
+	g_signal_connect (ep->settings, "changed::" EDITOR_SHOW_DROP_DOWN,
+	                  G_CALLBACK (on_notify_prefs), ep);
 	g_signal_connect (ep->settings, "changed::" EDITOR_TABS_HIDE,
 	                  G_CALLBACK (on_notify_prefs), ep);
 	g_signal_connect (ep->settings, "changed::" EDITOR_TABS_POS,
@@ -1668,6 +1611,7 @@ activate_plugin (AnjutaPlugin *plugin)
 
 	ui = dplugin->ui;
 	docman = anjuta_docman_new (dplugin);
+	gtk_widget_show (docman);
 	dplugin->docman = docman;
 
 	ANJUTA_DOCMAN(docman)->shell = anjuta_plugin_get_shell(plugin);
@@ -1677,8 +1621,6 @@ activate_plugin (AnjutaPlugin *plugin)
 					  G_CALLBACK (on_document_changed), plugin);
 	g_signal_connect (G_OBJECT (plugin->shell), "key-press-event",
 					  G_CALLBACK (on_window_key_press_event), plugin);
-	g_signal_connect (G_OBJECT (plugin->shell), "key-release-event",
-					  G_CALLBACK (on_window_key_release_event), plugin);
 
 	if (!initialized)
 	{
@@ -1724,9 +1666,14 @@ activate_plugin (AnjutaPlugin *plugin)
 
 	/* Add UI */
 	dplugin->uiid = anjuta_ui_merge (ui, UI_FILE);
-	dplugin->vbox = gtk_vbox_new (FALSE, 0);
+	dplugin->vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show (dplugin->vbox);
 	gtk_box_pack_start (GTK_BOX(dplugin->vbox), docman, TRUE, TRUE, 0);
+
+	/* Create the default searchbox instance. */
+	dplugin->search_box = search_box_new (ANJUTA_DOCMAN (docman));
+	gtk_box_pack_end (GTK_BOX (dplugin->vbox), dplugin->search_box, FALSE, FALSE, 0);
+
 	anjuta_shell_add_widget_full (plugin->shell, dplugin->vbox,
 							 "AnjutaDocumentManager", _("Documents"),
 							 "editor-plugin-icon",
@@ -1736,10 +1683,6 @@ activate_plugin (AnjutaPlugin *plugin)
 
 	ui_give_shorter_names (plugin);
 	update_document_ui (plugin, NULL);
-
-	/* Create the default searchbox instance, but don't yet put it into
-	   dplugin->vbox, to prevent the box being displayed at session start */
-	dplugin->search_box = search_box_new (ANJUTA_DOCMAN (docman));
 	
 	/* Setup popup menu */
 	popup_menu = gtk_ui_manager_get_widget (GTK_UI_MANAGER (ui),
@@ -1780,7 +1723,6 @@ deactivate_plugin (AnjutaPlugin *plugin)
 	// GtkIconFactory *icon_factory;
 	DocmanPlugin *eplugin;
 	AnjutaUI *ui;
-	AnjutaStatus *status;
 	GList *node;
 
 	DEBUG_PRINT ("%s", "DocmanPlugin: Deactivating document manager plugin…");
@@ -1793,7 +1735,6 @@ deactivate_plugin (AnjutaPlugin *plugin)
 										  G_CALLBACK (on_save_prompt), plugin);
 
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
-	status = anjuta_shell_get_status (plugin->shell, NULL);
 
 	g_signal_handlers_disconnect_by_func (G_OBJECT (eplugin->docman),
 										  G_CALLBACK (on_document_changed),
@@ -1801,15 +1742,11 @@ deactivate_plugin (AnjutaPlugin *plugin)
 	g_signal_handlers_disconnect_by_func (G_OBJECT (plugin->shell),
 										  G_CALLBACK (on_window_key_press_event),
 										  plugin);
-	g_signal_handlers_disconnect_by_func (G_OBJECT (plugin->shell),
-										  G_CALLBACK (on_window_key_release_event),
-										  plugin);
 
 	on_document_changed (ANJUTA_DOCMAN (eplugin->docman), NULL, plugin);
 
 	/* Widget is removed from the container when destroyed */
 	gtk_widget_destroy (eplugin->docman);
-	gtk_widget_destroy (eplugin->search_box);	/* the default searchbox instance may still be unparented */
 	g_object_unref (eplugin->bookmarks);
 	anjuta_ui_unmerge (ui, eplugin->uiid);
 	node = eplugin->action_groups;
@@ -1854,7 +1791,6 @@ docman_plugin_instance_init (GObject *obj)
 {
 	DocmanPlugin *plugin = ANJUTA_PLUGIN_DOCMAN (obj);
 	plugin->uiid = 0;
-	plugin->g_tabbing = FALSE;
 	plugin->notify_ids = NULL;
 	plugin->support_plugins = NULL;
 	plugin->settings = g_settings_new (PREF_SCHEMA);
@@ -2137,6 +2073,7 @@ ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError**
 	GError* error = NULL;
 	GtkBuilder* bxml = gtk_builder_new ();
 	DocmanPlugin* doc_plugin = ANJUTA_PLUGIN_DOCMAN (ipref);
+	GObject *show_tabs_radio, *tabs_settings_box;
 
 	/* Add preferences */
 	if (!gtk_builder_add_from_file (bxml, PREFS_BUILDER, &error))
@@ -2145,6 +2082,10 @@ ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError**
 		g_error_free (error);
 	}
 
+	show_tabs_radio = gtk_builder_get_object (bxml, "show-tabs-radio");
+	tabs_settings_box = gtk_builder_get_object (bxml, "tabs-settings-box");
+	g_object_bind_property (show_tabs_radio, "active", tabs_settings_box, "sensitive", 0);
+
 	anjuta_preferences_add_from_builder (prefs, bxml,
 	                                     doc_plugin->settings,
 	                                     "Documents", _("Documents"),  ICON_FILE);
