@@ -35,8 +35,9 @@
 #include "indentation.h"
 
 #define PREF_INDENT_BRACE_SIZE "indent-brace-size"
-#define PREF_INDENT_PARANTHESE_LINEUP "indent-paranthese-lineup"
-#define PREF_INDENT_PARANTHESE_SIZE "indent-paranthese-size"
+#define PREF_INDENT_PARENTHESIS_LINEUP "indent-parenthesis-lineup"
+#define PREF_INDENT_PARENTHESIS_SIZE "indent-parenthesis-size"
+#define PREF_INDENT_PARENTHESIS_ONLY_SPACES "indent-parenthesis-only-spaces"
 #define PREF_BRACE_AUTOCOMPLETION "brace-autocompletion"
 #define PREF_COMMENT_LEADING_ASTERISK "multiline-leading-asterisk"
 
@@ -132,29 +133,42 @@ get_line_indentation (IAnjutaEditor *editor, gint line_num)
 
 	line_end = ianjuta_editor_get_line_end_position (editor, line_num, NULL);
 
-	/* Find the line which contains the left brace matching last right brace on current line */
-
-	do
+	while (ianjuta_iterable_previous (line_end, NULL))
 	{
-		while (ianjuta_iterable_previous (line_end, NULL))
+		ch = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (line_end), 0, NULL);
+		if (ch == ')')
+			right_braces++;
+		if (ch == '(')
+			left_braces++;
+		if (iter_is_newline (line_end, ch))
 		{
-			ch = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (line_end), 0, NULL);
-			if (ch == ')')
-				right_braces++;
-			if (ch == '(')
-				left_braces++;
-			if (iter_is_newline (line_end, ch))
-			{
-				break;
-			}
+			break;
 		}
-		if (right_braces != left_braces)
+	}
+
+	/* Find the line which contains the left brace matching last right brace on current line */
+	if (right_braces > 0)
+	{
+		while (right_braces >= left_braces && line_num >= 0)
 		{
-			line_num --;
+			line_num--;
 			g_object_unref (line_end);
 			line_end = ianjuta_editor_get_line_end_position (editor, line_num, NULL);
+
+			while (ianjuta_iterable_previous (line_end, NULL))
+			{
+				ch = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (line_end), 0, NULL);
+				if (ch == ')')
+					right_braces++;
+				if (ch == '(')
+					left_braces++;
+				if (iter_is_newline (line_end, ch))
+				{
+					break;
+				}
+			}
 		}
-	} while (right_braces != left_braces && line_num >= 0);
+	}
 
 	g_object_unref (line_end);
 	line_begin = ianjuta_editor_get_line_begin_position (editor, line_num, NULL);
@@ -198,29 +212,41 @@ get_line_indentation (IAnjutaEditor *editor, gint line_num)
 }
 
 static gchar *
-get_line_indentation_string (IAnjutaEditor *editor, gint spaces, gint line_indent_spaces)
+get_line_indentation_string (IndentCPlugin *plugin, IAnjutaEditor *editor, gint indentation, gint parenthesis_indentation)
 {
 	gint i;
 	gchar *indent_string;
 
-	if ((spaces + line_indent_spaces) <= 0)
+	if ((indentation + parenthesis_indentation) <= 0)
 		return NULL;
 
 	if (USE_SPACES_FOR_INDENTATION)
 	{
-		indent_string = g_new0 (gchar, spaces + line_indent_spaces + 1);
-		for (i = 0; i < (spaces + line_indent_spaces); i++)
+		indent_string = g_new0 (gchar, indentation + parenthesis_indentation + 1);
+		for (i = 0; i < (indentation + parenthesis_indentation); i++)
 			indent_string[i] = ' ';
 	}
 	else
 	{
-		gint num_tabs = spaces / TAB_SIZE;
-		gint num_spaces = spaces % TAB_SIZE;
-		indent_string = g_new0 (gchar, num_tabs + num_spaces + line_indent_spaces + 1);
+		gint num_tabs, num_spaces;
+
+		if (g_settings_get_boolean (plugin->settings, PREF_INDENT_PARENTHESIS_ONLY_SPACES))
+		{
+			num_tabs = indentation / TAB_SIZE;
+			num_spaces = indentation % TAB_SIZE;
+		}
+		else
+		{
+			num_tabs = (indentation + parenthesis_indentation) / TAB_SIZE;
+			num_spaces = (indentation + parenthesis_indentation) % TAB_SIZE;
+			parenthesis_indentation = 0;
+		}
+
+		indent_string = g_new0 (gchar, num_tabs + num_spaces + parenthesis_indentation + 1);
 
 		for (i = 0; i < num_tabs; i++)
 			indent_string[i] = '\t';
-		for (; i < num_tabs + (num_spaces + line_indent_spaces); i++)
+		for (; i < num_tabs + (num_spaces + parenthesis_indentation); i++)
 			indent_string[i] = ' ';
 	}
 	return indent_string;
@@ -424,7 +450,7 @@ skip_preprocessor_lines (IAnjutaEditor *editor, IAnjutaIterable *iter)
 }
 
 static gint
-set_line_indentation (IAnjutaEditor *editor, gint line_num, gint indentation, gint line_indent_spaces)
+set_line_indentation (IndentCPlugin *plugin, IAnjutaEditor *editor, gint line_num, gint indentation, gint parenthesis_indentation)
 {
 	IAnjutaIterable *line_begin, *line_end, *indent_position;
 	IAnjutaIterable *current_pos;
@@ -470,9 +496,9 @@ set_line_indentation (IAnjutaEditor *editor, gint line_num, gint indentation, gi
 	//DEBUG_PRINT ("carat offset is = %d", carat_offset);
 
 	/* Set new indentation */
-	if ((indentation + line_indent_spaces) > 0)
+	if ((indentation + parenthesis_indentation) > 0)
 	{
-		indent_string = get_line_indentation_string (editor, indentation, line_indent_spaces);
+		indent_string = get_line_indentation_string (plugin, editor, indentation, parenthesis_indentation);
 		nchars = indent_string ? g_utf8_strlen (indent_string, -1) : 0;
 
 		/* Only indent if there is something to indent with */
@@ -509,7 +535,7 @@ set_line_indentation (IAnjutaEditor *editor, gint line_num, gint indentation, gi
 	/* If indentation == 0, we really didn't enter the previous code block,
 	 * but we may need to clear existing indentation.
 	 */
-	if ((indentation + line_indent_spaces) == 0)
+	if ((indentation + parenthesis_indentation) == 0)
 	{
 		/* Get existing indentation */
 		if (ianjuta_iterable_compare (indent_position, line_begin, NULL) > 0)
@@ -573,7 +599,7 @@ get_line_indentation_base (IndentCPlugin *plugin,
 						   IAnjutaEditor *editor,
 						   gint line_num,
 						   gint *incomplete_statement,
-						   gint *line_indent_spaces,
+						   gint *parenthesis_indentation,
 						   gboolean *colon_indent)
 {
 	IAnjutaIterable *iter;
@@ -591,7 +617,7 @@ get_line_indentation_base (IndentCPlugin *plugin,
 	IAnjutaIterable  *line_end = ianjuta_editor_get_line_end_position (editor, line_num, NULL);
 
 	*incomplete_statement = -1;
-	*line_indent_spaces = 0;
+	*parenthesis_indentation = 0;
 
 	if (line_num <= 1)
 		return 0;
@@ -843,7 +869,7 @@ get_line_indentation_base (IndentCPlugin *plugin,
 		{
 			line_indent = 0;
 			if (g_settings_get_boolean (plugin->settings,
-			                            PREF_INDENT_PARANTHESE_LINEUP))
+			                            PREF_INDENT_PARENTHESIS_LINEUP))
 			{
 				while (ianjuta_iterable_previous (iter, NULL))
 				{
@@ -857,9 +883,9 @@ get_line_indentation_base (IndentCPlugin *plugin,
 					if (dummy_ch == '\t')
 						line_indent += TAB_SIZE;
 					else
-						(*line_indent_spaces)++;
+						(*parenthesis_indentation)++;
 				}
-				(*line_indent_spaces)++;
+				(*parenthesis_indentation)++;
 				line_indent += extra_indent;
 			}
 			else
@@ -869,8 +895,8 @@ get_line_indentation_base (IndentCPlugin *plugin,
 				line_indent = get_line_indentation (editor, line_for_indent);
 				line_indent += extra_indent;
 
-				(*line_indent_spaces) += g_settings_get_int (plugin->settings,
-				                                             PREF_INDENT_PARANTHESE_SIZE);
+				(*parenthesis_indentation) += g_settings_get_int (plugin->settings,
+				                                             PREF_INDENT_PARENTHESIS_SIZE);
 			}
 
 			/* Although statement is incomplete at this point, we don't
@@ -1034,7 +1060,7 @@ spaces_only (IAnjutaEditor* editor, IAnjutaIterable* begin, IAnjutaIterable* end
 
 static gint
 get_line_auto_indentation (IndentCPlugin *plugin, IAnjutaEditor *editor,
-						   gint line, gint *line_indent_spaces)
+						   gint line, gint *parenthesis_indentation)
 {
 	IAnjutaIterable *iter;
 	IAnjutaIterable *end_iter;
@@ -1047,7 +1073,7 @@ get_line_auto_indentation (IndentCPlugin *plugin, IAnjutaEditor *editor,
 	/* be sure to set a default if we're in the first line otherwise
 	 * the pointer'll be left hanging with no value.
 	 */
-	*line_indent_spaces = 0;
+	*parenthesis_indentation = 0;
 
 	if (line == 1) /* First line */
 	{
@@ -1060,7 +1086,7 @@ get_line_auto_indentation (IndentCPlugin *plugin, IAnjutaEditor *editor,
 
 		if (spaces_only (editor, begin, end))
 		{
-			set_line_indentation (editor, line -1, 0, 0);
+			set_line_indentation (plugin, editor, line -1, 0, 0);
 		}
 		g_object_unref (begin);
 		g_object_unref (end);
@@ -1076,7 +1102,7 @@ get_line_auto_indentation (IndentCPlugin *plugin, IAnjutaEditor *editor,
 	{
 		line_indent = get_line_indentation_base (plugin, editor, line,
 												 &incomplete_statement,
-												 line_indent_spaces,
+												 parenthesis_indentation,
 												 &colon_indent);
 	}
 
@@ -1159,7 +1185,7 @@ get_line_auto_indentation (IndentCPlugin *plugin, IAnjutaEditor *editor,
 		else if (ch == '#')
 		{
 			line_indent = 0;
-			*line_indent_spaces = 0;
+			*parenthesis_indentation = 0;
 		}
 		else if (!isspace (ch))
 		{
@@ -1252,13 +1278,13 @@ cpp_java_indentation_char_added (IAnjutaEditor *editor,
 		{
 			gint insert_line;
 			gint line_indent;
-			gint line_indent_spaces;
+			gint parenthesis_indentation;
 
 			ianjuta_document_begin_undo_action (IANJUTA_DOCUMENT(editor), NULL);
 
 			insert_line = ianjuta_editor_get_lineno (editor, NULL);
-			line_indent = get_line_auto_indentation (plugin, editor, insert_line, &line_indent_spaces);
-			set_line_indentation (editor, insert_line, line_indent, line_indent_spaces);
+			line_indent = get_line_auto_indentation (plugin, editor, insert_line, &parenthesis_indentation);
+			set_line_indentation (plugin, editor, insert_line, line_indent, parenthesis_indentation);
 			ianjuta_document_end_undo_action (IANJUTA_DOCUMENT(editor), NULL);
 		}
 	}
@@ -1435,12 +1461,12 @@ cpp_auto_indentation (IAnjutaEditor *editor,
 
 	for (insert_line = line_start; insert_line <= line_end; insert_line++)
 	{
-		gint line_indent_spaces = 0;
+		gint parenthesis_indentation = 0;
 		line_indent = get_line_auto_indentation (lang_plugin, editor,
 		                                         insert_line,
-		                                         &line_indent_spaces);
+		                                         &parenthesis_indentation);
 		/* DEBUG_PRINT ("Line indent for line %d = %d", insert_line, line_indent); */
-		set_line_indentation (editor, insert_line, line_indent, line_indent_spaces);
+		set_line_indentation (lang_plugin, editor, insert_line, line_indent, parenthesis_indentation);
 	}
 	ianjuta_document_end_undo_action (IANJUTA_DOCUMENT(editor), NULL);
 }
