@@ -1,4 +1,4 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4; tab-width: 4 -*- */
 /*
     plugin.c
     Copyright (C) 2000 Naba Kumar
@@ -350,7 +350,8 @@ install_support (IndentCPlugin *lang_plugin)
         (g_str_equal (lang_plugin->current_language, "C")
         || g_str_equal (lang_plugin->current_language, "C++")
         || g_str_equal (lang_plugin->current_language, "Vala")
-        || g_str_equal (lang_plugin->current_language, "Java")))
+        || g_str_equal (lang_plugin->current_language, "Java")
+        || g_str_equal (lang_plugin->current_language, "JavaScript")))
     {
         g_signal_connect (lang_plugin->current_editor,
                           "char-added",
@@ -380,12 +381,13 @@ uninstall_support (IndentCPlugin *lang_plugin)
         (g_str_equal (lang_plugin->current_language, "C")
         || g_str_equal (lang_plugin->current_language, "C++")
         || g_str_equal (lang_plugin->current_language, "Vala")
-        || g_str_equal (lang_plugin->current_language, "Java")))
+        || g_str_equal (lang_plugin->current_language, "Java")
+        || g_str_equal (lang_plugin->current_language, "JavaScript")))
     {
         g_signal_handlers_disconnect_by_func (lang_plugin->current_editor,
                                     G_CALLBACK (cpp_java_indentation_char_added),
                                     lang_plugin);
-		g_signal_handlers_disconnect_by_func (lang_plugin->current_editor,
+        g_signal_handlers_disconnect_by_func (lang_plugin->current_editor,
                                     G_CALLBACK (cpp_java_indentation_changed),
                                     lang_plugin);
     }
@@ -500,8 +502,8 @@ indent_c_plugin_activate_plugin (AnjutaPlugin *plugin)
 
     ui = anjuta_shell_get_ui (plugin->shell, NULL);
     lang_plugin->action_group =
-        anjuta_ui_add_action_group_entries (ui, "ActionGroupCppJavaAssist",
-                                            _("C++/Java Assistance"),
+        anjuta_ui_add_action_group_entries (ui, "ActionGroupCIndent",
+                                            _("C Indentation"),
                                             actions,
                                             G_N_ELEMENTS (actions),
                                             GETTEXT_PACKAGE, TRUE,
@@ -531,6 +533,7 @@ indent_c_plugin_deactivate_plugin (AnjutaPlugin *plugin)
                                 TRUE);
 
     ui = anjuta_shell_get_ui (plugin->shell, NULL);
+    anjuta_ui_remove_action_group (ui, lang_plugin->action_group);
     anjuta_ui_unmerge (ui, lang_plugin->uiid);
 
     lang_plugin->uiid = 0;
