@@ -866,7 +866,7 @@ on_popup_add_to_project (GtkAction *action, ProjectManagerPlugin *plugin)
 }
 
 static void
-on_node_selected (GtkWidget *widget, AnjutaProjectNode *node,
+on_node_activated (GtkWidget *widget, AnjutaProjectNode *node,
 				  ProjectManagerPlugin *plugin)
 {
 	IAnjutaFileLoader *loader;
@@ -1575,7 +1575,7 @@ project_manager_plugin_activate_plugin (AnjutaPlugin *plugin)
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
 	g_signal_connect (view, "node-selected",
-					  G_CALLBACK (on_node_selected), plugin);
+					  G_CALLBACK (on_node_activated), plugin);
 	g_signal_connect (selection, "changed",
 					  G_CALLBACK (on_treeview_selection_changed), plugin);
 	g_signal_connect (view, "button-press-event",
@@ -2343,13 +2343,12 @@ ifile_open (IAnjutaFile *ifile, GFile* file, GError **e)
 	/* If there is already a project loaded, load in separate anjuta window */
 	if (plugin->project_root_uri)
 	{
-		gchar *uri = g_file_get_uri (file);
-		gchar *quoted_uri = g_shell_quote (uri);
-		gchar *cmd = g_strconcat ("anjuta --no-splash --no-client ", quoted_uri, NULL);
-		g_free (quoted_uri);
-		anjuta_util_execute_shell (NULL, cmd);
-		g_free (cmd);
-		g_free (uri);
+		AnjutaShell *shell;
+		IAnjutaFileLoader* loader;
+
+		shell = anjuta_shell_create_window (ANJUTA_PLUGIN (ifile)->shell, NULL);
+		loader = anjuta_shell_get_interface(shell, IAnjutaFileLoader, NULL);
+		ianjuta_file_loader_load(loader, file, FALSE, NULL);
 
 		return;
 	}
