@@ -316,9 +316,28 @@ row_activated (GtkTreeView       *tree_view,
 	node = gbf_tree_data_get_node (data);
 	if (node)
 	{
-		g_signal_emit (G_OBJECT (tree_view),
-			       signals [NODE_SELECTED], 0,
-			       node);
+		switch (anjuta_project_node_get_node_type (node))
+		{
+		case ANJUTA_PROJECT_GROUP:
+		case ANJUTA_PROJECT_ROOT:
+		case ANJUTA_PROJECT_TARGET:
+		case ANJUTA_PROJECT_MODULE:
+		case ANJUTA_PROJECT_PACKAGE:
+			if (!gtk_tree_view_row_expanded (tree_view, path))
+			{
+				gtk_tree_view_expand_row (tree_view, path, FALSE);
+			}
+			else
+			{
+				gtk_tree_view_collapse_row (tree_view, path);
+			}
+			break;
+		default:
+			g_signal_emit (G_OBJECT (tree_view),
+			               signals [NODE_SELECTED], 0,
+			               node);
+			break;
+		}
 	}
 }
 
@@ -379,15 +398,7 @@ get_icon (GFile *file)
 				       NULL,
 				       &error);
 
-	if (file_info == NULL)
-	{
-		pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default(),
-						   GTK_STOCK_MISSING_IMAGE,
-						   ICON_SIZE,
-						   GTK_ICON_LOOKUP_GENERIC_FALLBACK,
-						   NULL);
-	}
-	else
+	if (file_info != NULL)
 	{
 		icon = g_file_info_get_icon(file_info);
 		g_object_get (icon, "names", &icon_names, NULL);
@@ -395,11 +406,23 @@ get_icon (GFile *file)
 							icon_names,
 							ICON_SIZE,
 							GTK_ICON_LOOKUP_GENERIC_FALLBACK);
-		pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
-		gtk_icon_info_free(icon_info);
+		if (icon_info != NULL)
+		{
+			pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
+			gtk_icon_info_free(icon_info);
+		}
 		g_object_unref (file_info);
 	}
 
+	if (pixbuf == NULL)
+	{
+		pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default(),
+						   GTK_STOCK_MISSING_IMAGE,
+						   ICON_SIZE,
+						   GTK_ICON_LOOKUP_GENERIC_FALLBACK,
+						   NULL);
+	}
+
 	return pixbuf;
 }
 
